arcane_helper_utils library

Classes

CommonString
Provides a quick shortcut to common strings, such as punctuation marks that are otherwise cumbersome to find or type.
DoubleConverter
A JsonConverter that converts a nullable String? to a nullable double?.
FixedSizeList<T>
Represents a List with a fixed capacity.
IntegerConverter
A JsonConverter that converts a nullable String? to a nullable int?.
Ticker
Creates a Ticker that emits a tick every interval seconds until the timeout is reached.

Extensions

DaysInMonth on DateTime
An extension on DateTime to get the number of days in the current month.
DynamicPrintExtension on dynamic
FirstDayOfWeek on DateTime
An extension on DateTime to get the first day of the current week.
IsIntLeapYear on int
IsLeapYear on DateTime
IsToday on DateTime
An extension on DateTime to check if a date is today or if it is the same day as another date.
JsonValueListExtension on List<Object?>
Extension methods for JSON list serialization and deserialization.
JsonValueMapExtension on Map<Object?, Object?>
Extension methods for JSON map serialization.
JsonValueObjectExtension on Object?
Extension methods for recursively serializing and deserializing JSON-like values.
JWTMapUtility on JwtPayload
JWTUtility on String
An extension on String to extract useful information from JSON Web Tokens (JWT).
ListEquality on List<T?>?
Extension on nullable lists of nullable elements to provide a custom equality check.
ListNullability on List?
An extension on nullable List to provide convenience methods for checking nullability and emptiness.
Nullability on String?
An extension that adds convenience methods to handle nullability and emptiness checks for String? types.
Split on String
An extension on String to split the string into parts of a specified length.
StartAndEndOfPeriod on DateTime
An extension on DateTime to get the start and end of various time periods.
TextManipulation on String?
An extension on String to perform text manipulation tasks.
Unique on List<E>
An extension on List to filter out duplicate elements based on a specified identifier.
YesterdayAndTomorrow on DateTime
An extension that provides convenient getters to retrieve the start of yesterday and tomorrow for DateTime.

Typedefs

JwtPayload = Map<String, Object?>