arcane_helper_utils library
Classes
- CommonString
- Provides a quick shortcut to common strings, such as punctuation marks that are otherwise cumbersome to find or type.
- DoubleConverter
-
A
JsonConverterthat converts a nullableString?to a nullabledouble?. -
FixedSizeList<
T> -
Represents a
Listwith a fixed capacity. - IntegerConverter
-
A
JsonConverterthat converts a nullableString?to a nullableint?. - Ticker
-
Creates a Ticker that emits a tick every
intervalseconds until thetimeoutis reached.
Extensions
- DaysInMonth on DateTime
-
An extension on
DateTimeto get the number of days in the current month. - DynamicPrintExtension on dynamic
- FirstDayOfWeek on DateTime
-
An extension on
DateTimeto get the first day of the current week. - IsIntLeapYear on int
- IsLeapYear on DateTime
- IsToday on DateTime
-
An extension on
DateTimeto check if a date is today or if it is the same day as another date. -
JsonValueListExtension
on List<
Object?> - Extension methods for JSON list serialization and deserialization.
-
JsonValueMapExtension
on Map<
Object?, Object?> - Extension methods for JSON map serialization.
- JsonValueObjectExtension on Object?
- Extension methods for recursively serializing and deserializing JSON-like values.
- JWTMapUtility on JwtPayload
- JWTUtility on String
-
An extension on
Stringto extract useful information from JSON Web Tokens (JWT). -
ListEquality
on List<
T?> ? - Extension on nullable lists of nullable elements to provide a custom equality check.
- ListNullability on List?
-
An extension on nullable
Listto provide convenience methods for checking nullability and emptiness. - Nullability on String?
-
An extension that adds convenience methods to handle nullability and
emptiness checks for
String?types. - Split on String
-
An extension on
Stringto split the string into parts of a specified length. - StartAndEndOfPeriod on DateTime
-
An extension on
DateTimeto get the start and end of various time periods. - TextManipulation on String?
-
An extension on
Stringto perform text manipulation tasks. -
Unique
on List<
E> -
An extension on
Listto filter out duplicate elements based on a specified identifier. - YesterdayAndTomorrow on DateTime
-
An extension that provides convenient getters to retrieve the start of
yesterday and tomorrow for
DateTime.
Typedefs
-
JwtPayload
= Map<
String, Object?>